/************************************************************************/
/*																		*/
/*	Motor_Shield.h  This library supports the chipKIT motor shield,     */
/*                  in particular, providing an easy means of using     */
/*					the I/O extender                                 	*/
/*																		*/
/************************************************************************/
/*	Author: 	James Irwin 											*/
/*	Copyright 2013, Digilent Inc.										*/
/************************************************************************/
/*
  This library is free software; you can redistribute it and/or
  modify it under the terms of the GNU Lesser General Public
  License as published by the Free Software Foundation; either
  version 2.1 of the License, or (at your option) any later version.

  This library is distributed in the hope that it will be useful,
  but WITHOUT ANY WARRANTY; without even the implied warranty of
  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
  Lesser General Public License for more details.

  You should have received a copy of the GNU Lesser General Public
  License along with this library; if not, write to the Free Software
  Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA  02110-1301  USA
*/
/************************************************************************/
/*  Module Description: 												*/
/*																		*/
/*	This the Static Motor Shield Header file             				*/
/*																		*/
/************************************************************************/
/*  Revision History:													*/
/*																		*/
/*	 2/5/2013(JIrwin): Created											*/
/*																		*/
/************************************************************************/

#ifndef MOTORSHIELD_H
#define MOTORSHIELD_H

#include "WProgram.h"	
#include "..\Wire\Wire.h"




/*******************
 * Constants       *
 ******************/
 
 //unique I2C device address
 #define DEVADDR 	0x20
 
 //Register Addresses
 #define IODIR		0x00	//Data direction register (setting pins for input/output)
 #define IPOL		0x01
 #define GPINTEN	0x02
 #define DEFVAL		0x03
 #define INTCON		0x04
 #define IOCON		0x05
 #define GPPU		0x06
 #define INTF		0x07
 #define INTCAP		0x08
 #define GPIO		0x09	//the main data port for reading and writing
 #define OLAT		0x0A
 
 
 #define LEDMASK	0x0F
 #define BTNMASK	0xF0
 #define BTN1MASK	0x40
 #define BTN2MASK	0x80


/*******************
 * MotorShield Class
 ******************/

class MotorShield
{
	public:
	void begin(void);
	void writeLEDs(byte value);
	byte readInputs(void);
	void readButtons(bool* btn1, bool* btn2);
	
	private:
	void reorder_LEDs(byte* value);
	
};







#endif //MOTORSHIELD_H